ROTAMERS = {
    # Alanine
    "ALA": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
        ],
        "hydrogens": "H HA HB1 HB2 HB3".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB1"],
            ["CB", "HB2"],
            ["CB", "HB3"],
        ],
        "nchi": 0,
        "chi": {},
        "chi-rotate": {},
        "rotamers": [],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH3", "-0.120"],
            ["HB1", "H", "HCH3", "0.040"],
            ["HB2", "H", "HCH3", "0.040"],
            ["HB3", "H", "HCH3", "0.040"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "HB3"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "HB3": ["CB"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.521, 0.033], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.960, 0.020], "HB2": [0.960, 0.020], "HB3": [0.960, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.500, 1.500]],
            [["C", "CA", "CB"], [110.500, 1.500]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.400, 1.500]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "HB3"], [110.000, 3.000]],
            [["HB1", "CB", "HB3"], [110.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "HB3"], [109.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.6860]],
        ],
    },
    # Arginine
    "ARG": {
        "atoms": ["N", "CA", "C", "O", "CB", "CG", "CD", "NE", "CZ", "NH1", "NH2"],
        "hydrogens": "H HA HB2 HB3 HG2 HG3 HD2 HD3 HE HH11 HH12 HH21 HH22".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD"],
            ["CD", "NE"],
            ["NE", "CZ"],
            ["CZ", "NH1"],
            ["CZ", "NH2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG2"],
            ["CG", "HG3"],
            ["CD", "HD2"],
            ["CD", "HD3"],
            ["NE", "HE"],
            ["NH1", "HH11"],
            ["NH1", "HH12"],
            ["NH2", "HH21"],
            ["NH2", "HH22"],
        ],
        "nchi": 4,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD"],
            3: ["CB", "CG", "CD", "NE"],
            4: ["CG", "CD", "NE", "CZ"],
        },
        "chi-rotate": {
            1: [
                "CG",
                "CD",
                "NE",
                "CZ",
                "HB2",
                "HB3",
                "NH1",
                "NH2",
                "HH22",
                "HH21",
                "HH12",
                "HH11",
                "HE",
                "HD3",
                "HD2",
                "HG3",
                "HG2",
            ],
            2: [
                "CD",
                "NE",
                "CZ",
                "HG2",
                "HG3",
                "NH1",
                "NH2",
                "HH22",
                "HH21",
                "HH12",
                "HH11",
                "HE",
                "HD3",
                "HD2",
            ],
            3: [
                "NE",
                "CZ",
                "NH1",
                "NH2",
                "HD2",
                "HD3",
                "HE",
                "HH22",
                "HH21",
                "HH12",
                "HH11",
            ],
            4: ["CZ", "NH1", "NH2", "HE", "HH22", "HH21", "HH12", "HH11"],
        },
        "rotamers": [
            [62, 180, 65, 85],
            [62, 180, 65, -175],
            [62, 180, 180, 85],
            [62, 180, 180, 180],
            [62, 180, 180, -85],
            [62, 180, -65, 175],
            [62, 180, -65, -85],
            [-177, 65, 65, 85],
            [-177, 65, 65, -175],
            [-177, 65, 180, 85],
            [-177, 65, 180, 180],
            [-177, 180, 65, 85],
            [-177, 180, 65, -175],
            [-177, 180, 65, -105],
            [-177, 180, 180, 85],
            [-177, 180, 180, 180],
            [-177, 180, 180, -85],
            [-177, 180, -65, 105],
            [-177, 180, -65, 175],
            [-177, 180, -65, -85],
            [-67, 180, 65, 85],
            [-67, 180, 65, -175],
            [-67, 180, 65, -105],
            [-67, 180, 180, 85],
            [-67, 180, 180, 180],
            [-67, 180, 180, -85],
            [-67, 180, -65, 105],
            [-67, 180, -65, 175],
            [-67, -167, -65, -85],
            [-62, -68, 180, 85],
            [-62, -68, 180, 180],
            [-62, -68, 180, -85],
            [-62, -68, -65, 175],
            [-62, -68, -65, -85],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.274186, 5.009602, 1.194577],
            [3.881105, 5.817645, 2.426721],
            [4.540320, 7.142723, 2.424483],
            [4.364284, 8.040989, 3.389382],
            [3.575026, 7.807606, 4.434133],
            [5.006254, 9.201287, 3.286991],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.076"],
            ["HB1", "H", "HCH2", "0.038"],
            ["HB2", "H", "HCH2", "0.038"],
            ["CG", "C", "CH2", "-0.076"],
            ["HG1", "H", "HCH2", "0.038"],
            ["HG2", "H", "HCH2", "0.038"],
            ["CD", "C", "CH2", "-0.020"],
            ["HD1", "H", "HCH2", "0.066"],
            ["HD2", "H", "HCH2", "0.066"],
            ["NE", "N", "NC1", "-0.098"],
            ["HE", "H", "HNC1", "0.058"],
            ["CZ", "C", "C", "0.694"],
            ["NH1", "N", "NC2", "-0.278"],
            ["HH11", "H", "HNC2", "0.334"],
            ["HH12", "H", "HNC2", "0.334"],
            ["NH2", "N", "NC2", "-0.278"],
            ["HH21", "H", "HNC2", "0.334"],
            ["HH22", "H", "HNC2", "0.334"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD"],
            "HG1": ["CG"],
            "HG2": ["CG"],
            "CD": ["CG", "NE"],
            "HD1": ["CD"],
            "HD2": ["CD"],
            "NE": ["CD", "CZ"],
            "HE": ["NE"],
            "CZ": ["NE", "NH2"],
            "NH1": ["CZ", "HH12"],
            "HH11": ["NH1"],
            "HH12": ["NH1"],
            "NH2": ["CZ", "HH22"],
            "HH21": ["NH2"],
            "HH22": ["NH2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.520, 0.030]},
            "CG": {"HG1": [0.970, 0.020], "HG2": [0.970, 0.020], "CD": [1.520, 0.030]},
            "CD": {"HD1": [0.970, 0.020], "HD2": [0.970, 0.020], "NE": [1.460, 0.018]},
            "NE": {"HE": [0.860, 0.020], "CZ": [1.329, 0.014]},
            "CZ": {"NH1": [1.326, 0.018], "NH2": [1.326, 0.018]},
            "NH1": {"HH11": [0.860, 0.020], "HH12": [0.860, 0.020]},
            "NH2": {"HH21": [0.860, 0.020], "HH22": [0.860, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [114.100, 2.000]],
            [["HG1", "CG", "HG2"], [110.000, 3.000]],
            [["HG2", "CG", "CD"], [108.000, 3.000]],
            [["HG1", "CG", "CD"], [108.000, 3.000]],
            [["CB", "CG", "HG1"], [109.000, 3.000]],
            [["CB", "CG", "HG2"], [109.000, 3.000]],
            [["CB", "CG", "CD"], [111.300, 2.300]],
            [["HD1", "CD", "HD2"], [110.000, 3.000]],
            [["HD2", "CD", "NE"], [108.000, 3.000]],
            [["HD1", "CD", "NE"], [108.000, 3.000]],
            [["CG", "CD", "HD1"], [109.000, 3.000]],
            [["CG", "CD", "HD2"], [109.000, 3.000]],
            [["CG", "CD", "NE"], [112.000, 2.200]],
            [["HE", "NE", "CZ"], [117.900, 3.000]],
            [["CD", "NE", "HE"], [117.900, 3.000]],
            [["CD", "NE", "CZ"], [124.200, 1.500]],
            [["NH1", "CZ", "NH2"], [119.700, 1.800]],
            [["NE", "CZ", "NH1"], [120.000, 1.900]],
            [["HH11", "NH1", "HH12"], [120.000, 3.000]],
            [["CZ", "NH1", "HH11"], [120.000, 3.000]],
            [["CZ", "NH1", "HH12"], [120.000, 3.000]],
            [["NE", "CZ", "NH2"], [120.000, 1.900]],
            [["HH21", "NH2", "HH22"], [120.000, 3.000]],
            [["CZ", "NH2", "HH21"], [120.000, 3.000]],
            [["CZ", "NH2", "HH22"], [120.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.76]],
            [["CD", "NE", "CZ", "NH1"], [0.0]],
            [["CD", "NE", "CZ", "NH2"], [180.0]],
        ],
    },
    # Asparagine
    "ASN": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "OD1",
            "ND2",
        ],
        "hydrogens": "H HA HB2 HB3 HD21 HD22".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "OD1"],
            ["CG", "ND2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["ND2", "HD21"],
            ["ND2", "HD22"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "OD1"],
        },
        "chi-rotate": {
            1: ["CG", "OD1", "ND2", "HB2", "HB3", "HD21", "HD22"],
            2: ["OD1", "ND2", "HD21", "HD22"],
        },
        "rotamers": [
            [62, -10],
            [62, 30],
            [-174, -20],
            [-177, 30],
            [-65, -20],
            [-65, -75],
            [-65, 120],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.253700, 5.017112, 1.232144],
            [5.005299, 5.340406, 0.315072],
            [3.984885, 5.817909, 2.265917],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.045"],
            ["HB1", "H", "HCH2", "0.041"],
            ["HB2", "H", "HCH2", "0.041"],
            ["CG", "C", "C", "0.324"],
            ["OD1", "O", "O", "-0.425"],
            ["ND2", "N", "NH2", "-0.350"],
            ["HD21", "H", "HNH2", "0.207"],
            ["HD22", "H", "HNH2", "0.207"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "ND2"],
            "OD1": ["CG"],
            "ND2": ["CG", "HD22"],
            "HD21": ["ND2"],
            "HD22": ["ND2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.516, 0.025]},
            "CG": {"OD1": [1.231, 0.019], "ND2": [1.328, 0.021]},
            "ND2": {"HD21": [0.860, 0.020], "HD22": [0.860, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [112.600, 1.000]],
            [["OD1", "CG", "ND2"], [122.600, 1.000]],
            [["CB", "CG", "OD1"], [120.800, 2.000]],
            [["CB", "CG", "ND2"], [116.400, 1.500]],
            [["HD21", "ND2", "HD22"], [120.000, 3.000]],
            [["CG", "ND2", "HD21"], [120.000, 3.000]],
            [["CG", "ND2", "HD22"], [120.000, 3.000]],
            [["N", "CA", "C"], [112.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [123.2254]],
            [["CA", "CB", "CG", "ND2"], ["OD1"]],
        ],
    },
    # Aspartate
    "ASP": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "OD1",
            "OD2",
        ],
        "hydrogens": "H HA HB2 HB3 HD2".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "OD1"],
            ["CG", "OD2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["OD2", "HD2"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "OD1"],
        },
        "chi-rotate": {
            1: ["CG", "OD1", "OD2", "HB2", "HB3", "HD2"],
            2: ["OD1", "OD2", "HD2"],
        },
        "rotamers": [
            [62, -10],
            [62, 30],
            [-177, 0],
            [-177, 65],
            [-70, -15],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.275101, 5.011380, 1.194527],
            [3.669108, 5.954940, 0.620011],
            [5.407731, 5.091879, 1.740667],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.059"],
            ["HB1", "H", "HCH2", "0.042"],
            ["HB2", "H", "HCH2", "0.042"],
            ["CG", "C", "C", "0.207"],
            ["OD1", "O", "OC", "-0.616"],
            ["OD2", "O", "OC", "-0.616"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "OD2"],
            "OD1": ["CG"],
            "OD2": ["CG"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.516, 0.025]},
            "CG": {"OD1": [1.249, 0.019], "OD2": [1.249, 0.019]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [112.600, 1.000]],
            [["OD1", "CG", "OD2"], [122.900, 2.400]],
            [["CB", "CG", "OD1"], [118.400, 2.300]],
            [["CB", "CG", "OD2"], [118.400, 2.300]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.82]],
            [["CA", "CB", "CG", "OD2"], ["OD1"]],
        ],
    },
    # Cysteine
    "CYS": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "SG",
        ],
        "hydrogens": "H HA HB2 HB3 HG".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "SG"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["SG", "HG"],
        ],
        "nchi": 1,
        "chi": {
            1: ["N", "CA", "CB", "SG"],
        },
        "chi-rotate": {
            1: ["SG", "HB2", "HB3", "HG"],
        },
        "rotamers": [
            [62],
            [-177],
            [-65],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.309573, 5.303523, 1.366036],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.096"],
            ["HB1", "H", "HCH2", "0.046"],
            ["HB2", "H", "HCH2", "0.058"],
            ["SG", "S", "S", "0.004"],
            ["HG", "H", "H", "0.000"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "SG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "SG": ["CB"],
            "HG": ["SG"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "SG": [1.808, 0.033]},
            "HG": {"SG": [1.200, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "SG"], [108.000, 3.000]],
            [["HB1", "CB", "SG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "SG"], [114.400, 2.300]],
            [["CB", "SG", "HG"], [109.000, 5.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.5037]],
        ],
    },
    "GLN": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD",
            "OE1",
            "NE2",
        ],
        "hydrogens": "H HA HB2 HB3 HG2 HG3 HE21 HE22".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD"],
            ["CD", "OE1"],
            ["CD", "NE2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG2"],
            ["CG", "HG3"],
            ["NE2", "HE21"],
            ["NE2", "HE22"],
        ],
        "nchi": 3,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD"],
            3: ["CB", "CG", "CD", "OE1"],
        },
        "chi-rotate": {
            1: ["CG", "CD", "OE1", "NE2", "HB2", "HB3", "HG2", "HG3", "HE21", "HE22"],
            2: ["CD", "OE1", "NE2", "HG2", "HG3", "HE21", "HE22"],
            3: ["OE1", "NE2", "HE21", "HE22"],
        },
        "rotamers": [
            [62, 180, 20],
            [70, -75, 0],
            [-177, 65, -100],
            [-177, 65, 60],
            [-177, 180, 0],
            [-65, 85, 0],
            [-67, 180, -25],
            [-65, -65, -40],
            [-65, -65, 100],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.274186, 5.009602, 1.194577],
            [3.906976, 5.848443, 2.410302],
            [3.138962, 5.408349, 3.262893],
            [4.458856, 7.061523, 2.488333],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.078"],
            ["HB1", "H", "HCH2", "0.039"],
            ["HB2", "H", "HCH2", "0.039"],
            ["CG", "C", "CH2", "-0.040"],
            ["HG1", "H", "HCH2", "0.035"],
            ["HG2", "H", "HCH2", "0.035"],
            ["CD", "C", "C", "0.322"],
            ["OE1", "O", "O", "-0.422"],
            ["NE2", "N", "NH2", "-0.346"],
            ["HE21", "H", "HNH2", "0.208"],
            ["HE22", "H", "HNH2", "0.208"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD"],
            "HG1": ["CG"],
            "HG2": ["CG"],
            "CD": ["CG", "NE2"],
            "OE1": ["CD"],
            "NE2": ["CD", "HE22"],
            "HE21": ["NE2"],
            "HE22": ["NE2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.520, 0.030]},
            "CG": {"HG1": [0.970, 0.020], "HG2": [0.970, 0.020], "CD": [1.516, 0.025]},
            "CD": {"OE1": [1.231, 0.019], "NE2": [1.328, 0.021]},
            "NE2": {"HE21": [0.860, 0.020], "HE22": [0.860, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [114.100, 2.000]],
            [["HG1", "CG", "HG2"], [110.000, 3.000]],
            [["HG2", "CG", "CD"], [108.000, 3.000]],
            [["HG1", "CG", "CD"], [108.000, 3.000]],
            [["CB", "CG", "HG1"], [109.000, 3.000]],
            [["CB", "CG", "HG2"], [109.000, 3.000]],
            [["CB", "CG", "CD"], [112.600, 1.700]],
            [["OE1", "CD", "NE2"], [122.600, 1.000]],
            [["CG", "CD", "OE1"], [120.800, 2.000]],
            [["CG", "CD", "NE2"], [116.400, 1.500]],
            [["HE21", "NE2", "HE22"], [120.000, 3.000]],
            [["CD", "NE2", "HE21"], [120.000, 3.000]],
            [["CD", "NE2", "HE22"], [120.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.8134]],
            [["CB", "CG", "CD", "NE2"], ["OE1"]],
        ],
    },
    "GLU": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD",
            "OE1",
            "OE2",
        ],
        "hydrogens": "H HA HB2 HB3 HG2 HG3 HE2".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD"],
            ["CD", "OE1"],
            ["CD", "OE2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG2"],
            ["CG", "HG3"],
            ["OE2", "HE2"],
        ],
        "nchi": 3,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD"],
            3: ["CB", "CG", "CD", "OE1"],
        },
        "chi-rotate": {
            1: ["CG", "CD", "OE1", "OE2", "HB2", "HB3", "HG2", "HG3", "HE2"],
            2: ["CD", "OE1", "OE2", "HG2", "HG3", "HE2"],
            3: ["OE1", "OE2", "HE2"],
        },
        "rotamers": [
            [62, 180, -20],
            [70, -80, 0],
            [-177, 65, 10],
            [-177, 180, 0],
            [-177, -80, -25],
            [-65, 85, 0],
            [-67, 180, -10],
            [-65, -65, -40],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.267328, 4.996267, 1.194946],
            [3.873732, 5.805369, 2.428706],
            [4.594590, 5.679012, 3.454376],
            [2.855965, 6.542070, 2.333721],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.078"],
            ["HB1", "H", "HCH2", "0.039"],
            ["HB2", "H", "HCH2", "0.039"],
            ["CG", "C", "CH2", "-0.067"],
            ["HG1", "H", "HCH2", "0.041"],
            ["HG2", "H", "HCH2", "0.041"],
            ["CD", "C", "C", "0.203"],
            ["OE1", "O", "OC", "-0.609"],
            ["OE2", "O", "OC", "-0.609"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD"],
            "HG1": ["CG"],
            "HG2": ["CG"],
            "CD": ["CG", "OE2"],
            "OE1": ["CD"],
            "OE2": ["CD"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.520, 0.030]},
            "CG": {"HG1": [0.970, 0.020], "HG2": [0.970, 0.020], "CD": [1.516, 0.025]},
            "CD": {"OE1": [1.249, 0.019], "OE2": [1.249, 0.019]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [114.100, 2.000]],
            [["HG1", "CG", "HG2"], [110.000, 3.000]],
            [["HG2", "CG", "CD"], [108.000, 3.000]],
            [["HG1", "CG", "CD"], [108.000, 3.000]],
            [["CB", "CG", "HG1"], [109.000, 3.000]],
            [["CB", "CG", "HG2"], [109.000, 3.000]],
            [["CB", "CG", "CD"], [112.600, 1.700]],
            [["OE1", "CD", "OE2"], [122.900, 2.400]],
            [["CG", "CD", "OE1"], [118.400, 2.300]],
            [["CG", "CD", "OE2"], [118.400, 2.300]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.8702]],
            [["CB", "CG", "CD", "OE2"], ["OE1"]],
        ],
    },
    # Glycine
    "GLY": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
        ],
        "hydrogens": "H HA2 HA3".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["N", "H"],
            ["CA", "HA2"],
            ["CA", "HA3"],
        ],
        "nchi": 0,
        "chi": {},
        "chi-rotate": {},
        "rotamers": [],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.483710, 2.686702, -4.438857e-06],
            [5.993369, 1.568360, -8.469843e-06],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH2", "0.002"],
            ["HA1", "H", "HCH2", "0.051"],
            ["HA2", "H", "HCH2", "0.051"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA1": ["CA"],
            "HA2": ["CA"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.451, 0.016]},
            "CA": {"HA1": [0.970, 0.020], "HA2": [0.970, 0.020], "C": [1.516, 0.018]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA1", "CA", "HA2"], [109.000, 3.000]],
            [["HA2", "CA", "C"], [109.000, 3.000]],
            [["HA1", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA1"], [110.000, 3.000]],
            [["N", "CA", "HA2"], [110.000, 3.000]],
            [["N", "CA", "C"], [112.500, 2.900]],
            [["CA", "C", "O"], [120.800, 2.100]],
        ],
    },
    "HIS": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "ND1",
            "CD2",
            "CE1",
            "NE2",
        ],
        "hydrogens": "H HA HB2 HB3 HD1 HD2 HE1 HE2".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "ND1"],
            ["ND1", "CE1"],
            ["CE1", "NE2"],
            ["CD2", "NE2"],
            ["CD2", "CG"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["ND1", "HD1"],
            ["CD2", "HD2"],
            ["CE1", "HE1"],
            ["NE2", "HE2"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "ND1"],
        },
        "chi-rotate": {
            1: [
                "CG",
                "ND1",
                "CD2",
                "CE1",
                "NE2",
                "HB2",
                "HB3",
                "HD1",
                "HD2",
                "HE1",
                "HE2",
            ],
            2: ["ND1", "CD2", "CE1", "NE2", "HD1", "HD2", "HE1", "HE2"],
        },
        "rotamers": [
            [-65, 80],
            [-65, -70],
            [62, -75],
            [62, 80],
            [-177, -165],
            [-177, -80],
            [-177, 60],
            [-65, 165],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.200813, 5.026064, 1.321087],
            [3.942782, 5.885086, 2.382972],
            [5.058974, 5.678868, 0.492453],
            [4.624274, 6.997642, 2.182500],
            [5.294011, 6.891451, 1.061663],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.050"],
            ["HB1", "H", "HCH2", "0.041"],
            ["HB2", "H", "HCH2", "0.041"],
            ["CG", "C", "CR5", "0.048"],
            ["ND1", "N", "NR15", "0.013"],
            ["HD1", "H", "HNR5", "0.192"],
            ["CE1", "C", "CR15", "0.191"],
            ["HE1", "H", "HCR5", "0.068"],
            ["NE2", "N", "NR15", "-0.585"],
            ["HE2", "H", "HNR5", "1.000"],
            ["CD2", "C", "CR15", "-0.021"],
            ["HD2", "H", "HCR5", "0.062"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "ND1", "CD2"],
            "ND1": ["CG", "CE1"],
            "HD1": ["ND1"],
            "CE1": ["ND1", "NE2"],
            "HE1": ["CE1"],
            "NE2": ["CE1", "CD2"],
            "HE2": ["NE2"],
            "CD2": ["NE2", "HD2"],
            "HD2": ["CD2"],
            "C": ["CA", "END"],
            "O": ["C"],
            "CD2": ["CG", "NE2"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.497, 0.014]},
            "CG": {"CD2": [1.354, 0.011], "ND1": [1.378, 0.011]},
            "ND1": {"HD1": [0.860, 0.020], "CE1": [1.321, 0.010]},
            "CE1": {"HE1": [0.930, 0.020], "NE2": [1.321, 0.010]},
            "NE2": {"HE2": [0.860, 0.020], "CD2": [1.374, 0.011]},
            "CD2": {"HD2": [0.930, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [113.800, 1.000]],
            [["CB", "CG", "CD2"], [131.200, 1.300]],
            [["ND1", "CG", "CD2"], [106.100, 1.000]],
            [["CB", "CG", "ND1"], [122.700, 1.500]],
            [["HD1", "ND1", "CE1"], [125.350, 3.000]],
            [["CG", "ND1", "HD1"], [125.350, 3.000]],
            [["CG", "ND1", "CE1"], [109.300, 1.700]],
            [["HE1", "CE1", "NE2"], [125.800, 3.000]],
            [["ND1", "CE1", "HE1"], [125.800, 3.000]],
            [["ND1", "CE1", "NE2"], [108.400, 1.000]],
            [["HE2", "NE2", "CD2"], [125.500, 3.000]],
            [["CE1", "NE2", "HE2"], [125.500, 3.000]],
            [["CE1", "NE2", "CD2"], [109.000, 1.000]],
            [["NE2", "CD2", "HD2"], [126.400, 3.000]],
            [["CG", "CD2", "HD2"], [126.400, 3.000]],
            [["CG", "CD2", "NE2"], [107.200, 1.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.6711]],
            [["CA", "CB", "CG", "CD2"], ["ND1"]],
            [["CB", "CG", "ND1", "CE1"], [180]],
            [["CG", "ND1", "CE1", "NE2"], [0]],
        ],
    },
    "ILE": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG1",
            "CG2",
            "CD1",
        ],
        "hydrogens": "H HA HB HG12 HG13 HG21 HG22 HG23 HD11 HD12 HD13".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG1"],
            ["CB", "CG2"],
            ["CG1", "CD1"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB"],
            ["CG1", "HG12"],
            ["CG1", "HG13"],
            ["CG2", "HG21"],
            ["CG2", "HG22"],
            ["CG2", "HG23"],
            ["CD1", "HD11"],
            ["CD1", "HD12"],
            ["CD1", "HD13"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG1"],
            2: ["CA", "CB", "CG1", "CD1"],
        },
        "chi-rotate": {
            1: [
                "CG1",
                "CG2",
                "CD1",
                "HB",
                "HG12",
                "HG13",
                "HG21",
                "HG22",
                "HG23",
                "HD11",
                "HD12",
                "HD13",
            ],
            2: ["CD1", "HG12", "HG13", "HD11", "HD12", "HD13"],
        },
        "rotamers": [
            [62, 100],
            [62, 170],
            [-177, 66],
            [-177, 165],
            [-65, 100],
            [-65, 170],
            [-57, -60],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.552136, 3.620733, 1.245168],
            [4.230204, 4.986694, 1.245169],
            [3.970045, 2.845728, 2.490296],
            [3.812294, 5.761632, 2.490339],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH1", "-0.038"],
            ["HB", "H", "HCH1", "0.038"],
            ["CG1", "C", "CH2", "-0.076"],
            ["HG11", "H", "HCH2", "0.038"],
            ["HG12", "H", "HCH2", "0.038"],
            ["CD1", "C", "CH3", "-0.114"],
            ["HD11", "H", "HCH3", "0.038"],
            ["HD12", "H", "HCH3", "0.038"],
            ["HD13", "H", "HCH3", "0.038"],
            ["CG2", "C", "CH3", "-0.114"],
            ["HG21", "H", "HCH3", "0.038"],
            ["HG22", "H", "HCH3", "0.038"],
            ["HG23", "H", "HCH3", "0.038"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG2"],
            "HB": ["CB"],
            "CG1": ["CB", "CD1"],
            "HG11": ["CG1"],
            "HG12": ["CG1"],
            "CD1": ["CG1", "HD13"],
            "HD11": ["CD1"],
            "HD12": ["CD1"],
            "HD13": ["CD1"],
            "CG2": ["CB", "HG23"],
            "HG21": ["CG2"],
            "HG22": ["CG2"],
            "HG23": ["CG2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.540, 0.027], "C": [1.525, 0.021]},
            "CB": {"HB": [0.970, 0.020], "CG1": [1.530, 0.020], "CG2": [1.521, 0.033]},
            "CG1": {
                "HG11": [0.970, 0.020],
                "HG12": [0.970, 0.020],
                "CD1": [1.513, 0.039],
            },
            "CD1": {
                "HD11": [0.960, 0.020],
                "HD12": [0.960, 0.020],
                "HD13": [0.960, 0.020],
            },
            "CG2": {
                "HG21": [0.960, 0.020],
                "HG22": [0.960, 0.020],
                "HG23": [0.960, 0.020],
            },
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [109.100, 2.200]],
            [["C", "CA", "CB"], [109.100, 2.200]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [111.500, 1.700]],
            [["HB", "CB", "CG1"], [109.000, 3.000]],
            [["CG1", "CB", "CG2"], [110.700, 3.000]],
            [["HB", "CB", "CG2"], [109.000, 3.000]],
            [["CA", "CB", "HB"], [109.000, 3.000]],
            [["CA", "CB", "CG1"], [110.400, 1.700]],
            [["HG11", "CG1", "HG12"], [110.000, 3.000]],
            [["HG12", "CG1", "CD1"], [108.000, 3.000]],
            [["HG11", "CG1", "CD1"], [108.000, 3.000]],
            [["CB", "CG1", "HG11"], [109.000, 3.000]],
            [["CB", "CG1", "HG12"], [109.000, 3.000]],
            [["CB", "CG1", "CD1"], [113.800, 2.100]],
            [["HD11", "CD1", "HD12"], [110.000, 3.000]],
            [["HD12", "CD1", "HD13"], [110.000, 3.000]],
            [["HD11", "CD1", "HD13"], [110.000, 3.000]],
            [["CG1", "CD1", "HD11"], [109.000, 3.000]],
            [["CG1", "CD1", "HD12"], [109.000, 3.000]],
            [["CG1", "CD1", "HD13"], [109.000, 3.000]],
            [["CA", "CB", "CG2"], [110.500, 1.700]],
            [["HG21", "CG2", "HG22"], [110.000, 3.000]],
            [["HG22", "CG2", "HG23"], [110.000, 3.000]],
            [["HG21", "CG2", "HG23"], [110.000, 3.000]],
            [["CB", "CG2", "HG21"], [109.000, 3.000]],
            [["CB", "CG2", "HG22"], [109.000, 3.000]],
            [["CB", "CG2", "HG23"], [109.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.6711]],
            [["N", "CA", "CB", "CG2"], ["CG1", -123.2]],
        ],
    },
    "LEU": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD1",
            "CD2",
        ],
        "hydrogens": "H HA HB2 HB3 HG HD11 HD12 HD13 HD21 HD22 HD23".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD1"],
            ["CG", "CD2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG"],
            ["CD1", "HD11"],
            ["CD1", "HD12"],
            ["CD1", "HD13"],
            ["CD2", "HD21"],
            ["CD2", "HD22"],
            ["CD2", "HD23"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD1"],
        },
        "chi-rotate": {
            1: [
                "CG",
                "CD1",
                "CD2",
                "HB2",
                "HB3",
                "HG",
                "HD11",
                "HD12",
                "HD13",
                "HD21",
                "HD21",
                "HD23",
            ],
            2: ["CD1", "CD2", "HG", "HD11", "HD12", "HD13", "HD21", "HD22", "HD23"],
        },
        "rotamers": [
            [62, 80],
            [-177, 65],
            [-172, 145],
            [-85, 65],
            [-65, 175],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.274186, 5.009602, 1.194577],
            [3.853429, 5.762895, -0.062857],
            [3.881105, 5.817645, 2.426721],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.076"],
            ["HB1", "H", "HCH2", "0.038"],
            ["HB2", "H", "HCH2", "0.038"],
            ["CG", "C", "CH1", "-0.038"],
            ["HG", "H", "HCH1", "0.038"],
            ["CD1", "C", "CH3", "-0.114"],
            ["HD11", "H", "HCH3", "0.038"],
            ["HD12", "H", "HCH3", "0.038"],
            ["HD13", "H", "HCH3", "0.038"],
            ["CD2", "C", "CH3", "-0.114"],
            ["HD21", "H", "HCH3", "0.038"],
            ["HD22", "H", "HCH3", "0.038"],
            ["HD23", "H", "HCH3", "0.038"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD2"],
            "HG": ["CG"],
            "CD1": ["CG", "HD13"],
            "HD11": ["CD1"],
            "HD12": ["CD1"],
            "HD13": ["CD1"],
            "CD2": ["CG", "HD23"],
            "HD21": ["CD2"],
            "HD22": ["CD2"],
            "HD23": ["CD2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.530, 0.020]},
            "CG": {"HG": [0.970, 0.020], "CD1": [1.521, 0.033], "CD2": [1.521, 0.033]},
            "CD1": {
                "HD11": [0.960, 0.020],
                "HD12": [0.960, 0.020],
                "HD13": [0.960, 0.020],
            },
            "CD2": {
                "HD21": [0.960, 0.020],
                "HD22": [0.960, 0.020],
                "HD23": [0.960, 0.020],
            },
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [116.300, 3.500]],
            [["HG", "CG", "CD1"], [108.000, 3.000]],
            [["CD1", "CG", "CD2"], [110.800, 2.200]],
            [["HG", "CG", "CD2"], [108.000, 3.000]],
            [["CB", "CG", "HG"], [109.000, 3.000]],
            [["CB", "CG", "CD1"], [110.700, 3.000]],
            [["HD11", "CD1", "HD12"], [110.000, 3.000]],
            [["HD12", "CD1", "HD13"], [110.000, 3.000]],
            [["HD11", "CD1", "HD13"], [110.000, 3.000]],
            [["CG", "CD1", "HD11"], [109.000, 3.000]],
            [["CG", "CD1", "HD12"], [109.000, 3.000]],
            [["CG", "CD1", "HD13"], [109.000, 3.000]],
            [["CB", "CG", "CD2"], [110.700, 3.000]],
            [["HD21", "CD2", "HD22"], [110.000, 3.000]],
            [["HD22", "CD2", "HD23"], [110.000, 3.000]],
            [["HD21", "CD2", "HD23"], [110.000, 3.000]],
            [["CG", "CD2", "HD21"], [109.000, 3.000]],
            [["CG", "CD2", "HD22"], [109.000, 3.000]],
            [["CG", "CD2", "HD23"], [109.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.49]],
            [["CA", "CB", "CG", "CD2"], ["CD1", -108.2]],
        ],
    },
    "LYS": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD",
            "CE",
            "NZ",
        ],
        "hydrogens": "H HA HB2 HB3 HG2 HG3 HD2 HD3 HE2 HE3 HZ1 HZ2 HZ3".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD"],
            ["CD", "CE"],
            ["CE", "NZ"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG2"],
            ["CG", "HG3"],
            ["CD", "HD2"],
            ["CD", "HD3"],
            ["CE", "HE2"],
            ["CE", "HE3"],
            ["NZ", "HZ1"],
            ["NZ", "HZ2"],
            ["NZ", "HZ3"],
        ],
        "nchi": 4,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD"],
            3: ["CB", "CG", "CD", "CE"],
            4: ["CG", "CD", "CE", "NZ"],
        },
        "chi-rotate": {
            1: [
                "CG",
                "CD",
                "CE",
                "NZ",
                "HB2",
                "HB3",
                "HG2",
                "HG3",
                "HD2",
                "HD3",
                "HE2",
                "HE3",
                "HZ1",
                "HZ2",
                "HZ3",
            ],
            2: [
                "CD",
                "CE",
                "NZ",
                "HG2",
                "HG3",
                "HD2",
                "HD3",
                "HE2",
                "HE3",
                "HZ1",
                "HZ2",
                "HZ3",
            ],
            3: ["CE", "NZ", "HD2", "HD3", "HE2", "HE3", "HZ1", "HZ2", "HZ3"],
            4: ["NZ", "HE2", "HE3", "HZ1", "HZ2", "HZ3"],
        },
        "rotamers": [
            [62, 180, 68, 180],
            [62, 180, 180, 65],
            [62, 180, 180, 180],
            [62, 180, 180, -65],
            [62, 180, -68, 180],
            [-177, 68, 180, 65],
            [-177, 68, 180, 180],
            [-177, 68, 180, -65],
            [-177, 180, 68, 65],
            [-177, 180, 68, 180],
            [-177, 180, 180, 65],
            [-177, 180, 180, 180],
            [-177, 180, 180, -65],
            [-177, 180, -68, 180],
            [-177, 180, -68, -65],
            [-90, 68, 180, 180],
            [-67, 180, 68, 65],
            [-67, 180, 68, 180],
            [-67, 180, 180, 65],
            [-67, 180, 180, 180],
            [-67, 180, 180, -65],
            [-67, 180, -68, 180],
            [-67, 180, -68, -65],
            [-62, -68, 180, 65],
            [-62, -68, 180, 180],
            [-62, -68, 180, -65],
            [-62, -68, -68, 180],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.274186, 5.009602, 1.194577],
            [3.881105, 5.817645, 2.426721],
            [4.578325, 7.173410, 2.389153],
            [4.199422, 7.952309, 3.576860],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.076"],
            ["HB1", "H", "HCH2", "0.038"],
            ["HB2", "H", "HCH2", "0.038"],
            ["CG", "C", "CH2", "-0.076"],
            ["HG1", "H", "HCH2", "0.038"],
            ["HG2", "H", "HCH2", "0.038"],
            ["CD", "C", "CH2", "-0.076"],
            ["HD1", "H", "HCH2", "0.038"],
            ["HD2", "H", "HCH2", "0.038"],
            ["CE", "C", "CH2", "-0.013"],
            ["HE1", "H", "HCH2", "0.098"],
            ["HE2", "H", "HCH2", "0.098"],
            ["NZ", "N", "NT3", "-0.506"],
            ["HZ1", "H", "HNT3", "0.441"],
            ["HZ2", "H", "HNT3", "0.441"],
            ["HZ3", "H", "HNT3", "0.441"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD"],
            "HG1": ["CG"],
            "HG2": ["CG"],
            "CD": ["CG", "CE"],
            "HD1": ["CD"],
            "HD2": ["CD"],
            "CE": ["CD", "NZ"],
            "HE1": ["CE"],
            "HE2": ["CE"],
            "NZ": ["CE", "HZ3"],
            "HZ1": ["NZ"],
            "HZ2": ["NZ"],
            "HZ3": ["NZ"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.520, 0.030]},
            "CG": {"HG1": [0.970, 0.020], "HG2": [0.970, 0.020], "CD": [1.520, 0.030]},
            "CD": {"HD1": [0.970, 0.020], "HD2": [0.970, 0.020], "CE": [1.520, 0.030]},
            "CE": {"HE1": [0.970, 0.020], "HE2": [0.970, 0.020], "NZ": [1.489, 0.030]},
            "NZ": {"HZ1": [0.890, 0.020], "HZ2": [0.890, 0.020], "HZ3": [0.890, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [114.100, 2.000]],
            [["HG1", "CG", "HG2"], [110.000, 3.000]],
            [["HG2", "CG", "CD"], [108.000, 3.000]],
            [["HG1", "CG", "CD"], [108.000, 3.000]],
            [["CB", "CG", "HG1"], [109.000, 3.000]],
            [["CB", "CG", "HG2"], [109.000, 3.000]],
            [["CB", "CG", "CD"], [111.300, 2.300]],
            [["HD1", "CD", "HD2"], [110.000, 3.000]],
            [["HD2", "CD", "CE"], [108.000, 3.000]],
            [["HD1", "CD", "CE"], [108.000, 3.000]],
            [["CG", "CD", "HD1"], [109.000, 3.000]],
            [["CG", "CD", "HD2"], [109.000, 3.000]],
            [["CG", "CD", "CE"], [111.300, 2.300]],
            [["HE1", "CE", "HE2"], [110.000, 3.000]],
            [["HE2", "CE", "NZ"], [108.000, 3.000]],
            [["HE1", "CE", "NZ"], [108.000, 3.000]],
            [["CD", "CE", "HE1"], [109.000, 3.000]],
            [["CD", "CE", "HE2"], [109.000, 3.000]],
            [["CD", "CE", "NZ"], [111.900, 3.200]],
            [["HZ1", "NZ", "HZ2"], [109.000, 3.000]],
            [["HZ2", "NZ", "HZ3"], [109.000, 3.000]],
            [["HZ1", "NZ", "HZ3"], [109.000, 3.000]],
            [["CE", "NZ", "HZ1"], [110.000, 3.000]],
            [["CE", "NZ", "HZ2"], [110.000, 3.000]],
            [["CE", "NZ", "HZ3"], [110.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.49]],
        ],
    },
    "MET": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "SD",
            "CE",
        ],
        "hydrogens": "H HA HB2 HB3 HG2 HG3 HE1 HE2 HE3".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "SD"],
            ["SD", "CE"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG2"],
            ["CG", "HG3"],
            ["CE", "HE1"],
            ["CE", "HE2"],
            ["CE", "HE3"],
        ],
        "nchi": 3,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "SD"],
            3: ["CB", "CG", "SD", "CE"],
        },
        "chi-rotate": {
            1: ["CG", "SD", "CE", "HB2", "HB3", "HG2", "HG3", "HE1", "HE2", "HE3"],
            2: ["SD", "CE", "HG2", "HG3", "HE1", "HE2", "HE3"],
            3: ["CE", "HE1", "HE2", "HE3"],
        },
        "rotamers": [
            [62, 180, 75],
            [62, 180, -75],
            [-177, 65, 75],
            [-177, 65, 180],
            [-177, 180, 75],
            [-177, 180, 180],
            [-177, 180, -75],
            [-67, 180, 75],
            [-67, 180, 180],
            [-67, 180, -75],
            [-65, -65, 103],
            [-65, -65, 180],
            [-65, -65, -70],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.274186, 5.009602, 1.194577],
            [3.817309, 5.981266, 2.651708],
            [4.753212, 7.463128, 2.340949],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.076"],
            ["HB1", "H", "HCH2", "0.038"],
            ["HB2", "H", "HCH2", "0.038"],
            ["CG", "C", "CH2", "-0.024"],
            ["HG1", "H", "HCH2", "0.041"],
            ["HG2", "H", "HCH2", "0.041"],
            ["SD", "S", "S", "-0.058"],
            ["CE", "C", "CH3", "-0.150"],
            ["HE1", "H", "HCH3", "0.050"],
            ["HE2", "H", "HCH3", "0.050"],
            ["HE3", "H", "HCH3", "0.050"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "SD"],
            "HG1": ["CG"],
            "HG2": ["CG"],
            "SD": ["CG", "CE"],
            "CE": ["SD", "HE3"],
            "HE1": ["CE"],
            "HE2": ["CE"],
            "HE3": ["CE"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.520, 0.030]},
            "CG": {"HG1": [0.970, 0.020], "HG2": [0.970, 0.020], "SD": [1.803, 0.025]},
            "SD": {"CE": [1.791, 0.025]},
            "CE": {"HE1": [0.960, 0.020], "HE2": [0.960, 0.020], "HE3": [0.960, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [110.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [114.100, 2.000]],
            [["HG1", "CG", "HG2"], [110.000, 3.000]],
            [["HG2", "CG", "SD"], [108.000, 3.000]],
            [["HG1", "CG", "SD"], [108.000, 3.000]],
            [["CB", "CG", "HG1"], [109.000, 3.000]],
            [["CB", "CG", "HG2"], [109.000, 3.000]],
            [["CB", "CG", "SD"], [112.700, 3.000]],
            [["CG", "SD", "CE"], [100.900, 2.200]],
            [["HE1", "CE", "HE2"], [110.000, 3.000]],
            [["HE2", "CE", "HE3"], [110.000, 3.000]],
            [["HE1", "CE", "HE3"], [110.000, 3.000]],
            [["SD", "CE", "HE1"], [109.000, 3.000]],
            [["SD", "CE", "HE2"], [109.000, 3.000]],
            [["SD", "CE", "HE3"], [109.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.49]],
        ],
    },
    "PHE": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD1",
            "CD2",
            "CE1",
            "CE2",
            "CZ",
        ],
        "hydrogens": "H HA HB2 HB3 HD1 HD2 HE1 HE2 HZ".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD1"],
            ["CG", "CD2"],
            ["CD1", "CE1"],
            ["CD2", "CE2"],
            ["CE1", "CZ"],
            ["CE2", "CZ"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CD1", "HD1"],
            ["CD2", "HD2"],
            ["CE1", "HE1"],
            ["CE2", "HE2"],
            ["CZ", "HZ"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD1"],
        },
        "chi-rotate": {
            1: [
                "CG",
                "CD1",
                "CD2",
                "CE1",
                "CE2",
                "CZ",
                "HB2",
                "HB3",
                "HD1",
                "HD2",
                "HE1",
                "HE2",
                "HZ",
            ],
            2: ["CD1", "CD2", "CE1", "CE2", "CZ", "HD1", "HD2", "HE1", "HE2", "HZ"],
        },
        "rotamers": [
            [62, 90],
            [62, -90],
            [-177, 80],
            [-177, -80],
            [-65, -85],
            [-65, 85],
            [-65, -30],
            [-65, 30],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.200813, 5.026064, 1.321087],
            [3.911613, 5.857250, 2.409890],
            [5.068419, 5.467143, 0.314744],
            [4.490014, 7.129513, 2.492354],
            [5.646818, 6.739407, 0.397211],
            [5.357616, 7.570591, 1.486016],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.134"],
            ["HB1", "H", "HCH2", "0.067"],
            ["HB2", "H", "HCH2", "0.067"],
            ["CG", "C", "CR6", "-0.037"],
            ["CD1", "C", "CR16", "-0.090"],
            ["HD1", "H", "HCR6", "0.053"],
            ["CE1", "C", "CR16", "-0.053"],
            ["HE1", "H", "HCR6", "0.053"],
            ["CZ", "C", "CR16", "-0.053"],
            ["HZ", "H", "HCR6", "0.053"],
            ["CE2", "C", "CR16", "-0.053"],
            ["HE2", "H", "HCR6", "0.053"],
            ["CD2", "C", "CR16", "-0.053"],
            ["HD2", "H", "HCR6", "0.053"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD1"],
            "CD1": ["CG", "CE1"],
            "HD1": ["CD1"],
            "CE1": ["CD1", "CZ"],
            "HE1": ["CE1"],
            "CZ": ["CE1", "CE2"],
            "HZ": ["CZ"],
            "CE2": ["CD2", "CZ"],
            "HE2": ["CE2"],
            "CD2": ["CE2", "HD2"],
            "HD2": ["CD2"],
            "C": ["CA", "END"],
            "O": ["C"],
            "CD2": ["CG", "ADD"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.502, 0.023]},
            "CG": {"CD2": [1.384, 0.021], "CD1": [1.384, 0.021]},
            "CD1": {"HD1": [0.930, 0.020], "CE1": [1.382, 0.030]},
            "CE1": {"HE1": [0.930, 0.020], "CZ": [1.382, 0.030]},
            "CZ": {"HZ": [0.930, 0.020], "CE2": [1.382, 0.030]},
            "CE2": {"HE2": [0.930, 0.020], "CD2": [1.382, 0.030]},
            "CD2": {"HD2": [0.930, 0.020], "CE2": [1.382, 0.030]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [113.800, 1.000]],
            [["CB", "CG", "CD2"], [120.700, 1.700]],
            [["CD1", "CG", "CD2"], [118.600, 1.500]],
            [["CB", "CG", "CD1"], [120.700, 1.700]],
            [["HD1", "CD1", "CE1"], [119.650, 3.000]],
            [["CG", "CD1", "HD1"], [119.650, 3.000]],
            [["CG", "CD1", "CE1"], [120.700, 1.700]],
            [["CG", "CD2", "HD2"], [119.650, 3.000]],
            [["CE2", "CD2", "HD2"], [119.650, 3.000]],
            [["CG", "CD2", "CE2"], [120.700, 1.700]],
            [["HE1", "CE1", "CZ"], [120.000, 3.000]],
            [["CD1", "CE1", "HE1"], [120.000, 3.000]],
            [["CD1", "CE1", "CZ"], [120.000, 1.800]],
            [["HZ", "CZ", "CE2"], [120.000, 3.000]],
            [["CE1", "CZ", "HZ"], [120.000, 3.000]],
            [["CE1", "CZ", "CE2"], [120.000, 1.800]],
            [["HE2", "CE2", "CD2"], [120.000, 3.000]],
            [["CZ", "CE2", "HE2"], [120.000, 3.000]],
            [["CZ", "CE2", "CD2"], [120.000, 1.800]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.49]],
            [["CA", "CB", "CG", "CD2"], ["CD1", 180.0]],
            [["CB", "CG", "CD1", "CE1"], [180]],
            [["CB", "CG", "CD2", "CE2"], [180]],
            [["CG", "CD1", "CE1", "CZ"], [0]],
        ],
    },
    # Proline
    "PRO": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD",
        ],
        "hydrogens": "H HA HB2 HB3 HG2 HG3 HD2 HD3".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD"],
            ["CD", "N"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG2"],
            ["CG", "HG3"],
            ["CD", "HD2"],
            ["CD", "HD3"],
        ],
        "nchi": 1,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD"],
        },
        "chi-rotate": {
            1: ["CG", "HB2", "HB3", "HG2", "HG3", "HD2", "HD3"],
        },
        "rotamers": [
            [30, -30],
            [-30, 30],
        ],
        "positions": [
            [3.326834, 1.557389, -1.603945e-06],
            [3.933610, 2.871277, -0.104508],
            [3.505164, 3.526392, -1.409783],
            [2.754240, 2.939065, -2.185412],
            [5.369091, 2.628184, 0.185227],
            [5.547126, 1.172441, 0.544693],
            [4.302147, 0.476598, 0.080119],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "N", "-0.048"],
            ["CA", "C", "CH1", "0.038"],
            ["HA", "H", "HCH1", "0.048"],
            ["CB", "C", "CH2", "-0.076"],
            ["HB1", "H", "HCH2", "0.038"],
            ["HB2", "H", "HCH2", "0.038"],
            ["CG", "C", "CH2", "-0.076"],
            ["HG1", "H", "HCH2", "0.038"],
            ["HG2", "H", "HCH2", "0.038"],
            ["CD", "C", "CH2", "-0.030"],
            ["HD1", "H", "HCH2", "0.047"],
            ["HD2", "H", "HCH2", "0.047"],
            ["C", "C", "C", "0.323"],
            ["O", "O", "O", "-0.425"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD"],
            "HG1": ["CG"],
            "HG2": ["CG"],
            "CD": ["CG", "HD2", "N"],
            "HD1": ["CD"],
            "HD2": ["CD"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"CA": [1.466, 0.015]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.492, 0.050]},
            "CG": {"HG1": [0.970, 0.020], "HG2": [0.970, 0.020], "CD": [1.503, 0.034]},
            "CD": {"HD1": [0.970, 0.020], "HD2": [0.970, 0.020], "N": [1.473, 0.014]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["CA", "N", "CD"], [112.000, 1.400]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [103.000, 1.100]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [110.000, 3.000]],
            [["HB1", "CB", "CG"], [110.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [104.500, 1.900]],
            [["HG1", "CG", "HG2"], [110.000, 3.000]],
            [["HG2", "CG", "CD"], [110.000, 3.000]],
            [["HG1", "CG", "CD"], [110.000, 3.000]],
            [["CB", "CG", "HG1"], [109.000, 3.000]],
            [["CB", "CG", "HG2"], [109.000, 3.000]],
            [["CB", "CG", "CD"], [106.100, 3.200]],
            [["HD1", "CD", "HD2"], [110.000, 3.000]],
            [["CG", "CD", "HD1"], [109.000, 3.000]],
            [["CG", "CD", "HD2"], [109.000, 3.000]],
            [["N", "CD", "CG"], [103.200, 1.500]],
            [["N", "CD", "HD1"], [109.000, 3.000]],
            [["N", "CD", "HD2"], [109.000, 3.000]],
            [["N", "CA", "C"], [111.800, 2.500]],
            [["CA", "C", "O"], [119.000, 3.000]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [115.29]],
        ],
    },
    # Serine
    "SER": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "OG",
        ],
        "hydrogens": "H HA HB2 HB3 HG".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "OG"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["OG", "HG"],
        ],
        "nchi": 1,
        "chi": {
            1: ["N", "CA", "CB", "OG"],
        },
        "chi-rotate": {
            1: ["OG", "HB2", "HB3", "HG"],
        },
        "rotamers": [
            [62],
            [-177],
            [-65],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.230753, 4.925145, 1.196917],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.040"],
            ["HB1", "H", "HCH2", "0.053"],
            ["HB2", "H", "HCH2", "0.053"],
            ["OG", "O", "OH1", "-0.448"],
            ["HG", "H", "HOH1", "0.302"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "OG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "OG": ["CB", "HG"],
            "HG": ["OG"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "OG": [1.417, 0.020]},
            "OG": {"HG": [0.820, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "OG"], [109.000, 3.000]],
            [["HB1", "CB", "OG"], [109.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "OG"], [111.100, 2.000]],
            [["CB", "OG", "HG"], [110.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.66]],
        ],
    },
    # Threonine
    "THR": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "OG1",
            "CG2",
        ],
        "hydrogens": "H HA HB HG1 HG21 HG22 HG23".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "OG1"],
            ["CB", "CG2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB"],
            ["OG1", "HG1"],
            ["CG2", "HG21"],
            ["CG2", "HG22"],
            ["CG2", "HG23"],
        ],
        "nchi": 1,
        "chi": {
            1: ["N", "CA", "CB", "OG1"],
        },
        "chi-rotate": {
            1: ["OG1", "CG2", "HB", "HG1", "HG21", "HG22", "HG23"],
        },
        "rotamers": [
            [62],
            [-175],
            [-65],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [3.971501, 2.947413, 2.411212],
            [2.065936, 3.859425, 1.244383],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH1", "0.089"],
            ["HB", "H", "HCH1", "0.050"],
            ["OG1", "O", "OH1", "-0.441"],
            ["HG1", "H", "HOH1", "0.302"],
            ["CG2", "C", "CH3", "-0.120"],
            ["HG21", "H", "HCH3", "0.040"],
            ["HG22", "H", "HCH3", "0.040"],
            ["HG23", "H", "HCH3", "0.040"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG2"],
            "HB": ["CB"],
            "OG1": ["CB", "HG1"],
            "HG1": ["OG1"],
            "CG2": ["CB", "HG23"],
            "HG21": ["CG2"],
            "HG22": ["CG2"],
            "HG23": ["CG2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.540, 0.027], "C": [1.525, 0.021]},
            "CB": {"HB": [0.970, 0.020], "OG1": [1.433, 0.016], "CG2": [1.521, 0.033]},
            "OG1": {"HG1": [0.820, 0.020]},
            "CG2": {
                "HG21": [0.960, 0.020],
                "HG22": [0.960, 0.020],
                "HG23": [0.960, 0.020],
            },
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [109.100, 2.200]],
            [["C", "CA", "CB"], [109.100, 2.200]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [111.500, 1.700]],
            [["HB", "CB", "OG1"], [109.000, 3.000]],
            [["OG1", "CB", "CG2"], [109.300, 2.000]],
            [["HB", "CB", "CG2"], [108.000, 3.000]],
            [["CA", "CB", "HB"], [109.000, 3.000]],
            [["CA", "CB", "OG1"], [109.600, 1.500]],
            [["CB", "OG1", "HG1"], [110.000, 3.000]],
            [["CA", "CB", "CG2"], [110.500, 1.700]],
            [["HG21", "CG2", "HG22"], [109.000, 3.000]],
            [["HG22", "CG2", "HG23"], [109.000, 3.000]],
            [["HG21", "CG2", "HG23"], [109.000, 3.000]],
            [["CB", "CG2", "HG21"], [110.000, 3.000]],
            [["CB", "CG2", "HG22"], [110.000, 3.000]],
            [["CB", "CG2", "HG23"], [110.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.66]],
            [["N", "CA", "CB", "CG2"], ["OG1", -120.0]],
        ],
    },
    # Tryptophan
    "TRP": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD1",
            "CD2",
            "NE1",
            "CE2",
            "CE3",
            "CZ2",
            "CZ3",
            "CH2",
        ],
        "hydrogens": "H HA HB2 HB3 HD1 HE1 HE3 HZ2 HZ3 HH2".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD1"],
            ["CG", "CD2"],
            ["CD1", "NE1"],
            ["NE1", "CE2"],
            ["CD2", "CE2"],
            ["CD2", "CE3"],
            ["CE2", "CZ2"],
            ["CE3", "CZ3"],
            ["CZ2", "CH2"],
            ["CZ3", "CH2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CD1", "HD1"],
            ["NE1", "HE1"],
            ["CE3", "HE3"],
            ["CZ2", "HZ2"],
            ["CZ3", "HZ3"],
            ["CH2", "HH2"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD1"],
        },
        "chi-rotate": {
            1: [
                "CG",
                "CD1",
                "CD2",
                "NE1",
                "CE2",
                "CE3",
                "CZ2",
                "CZ3",
                "CH2",
                "HB2",
                "HB3",
                "HD1",
                "HE1",
                "HE3",
                "HZ2",
                "HZ3",
                "HH2",
            ],
            2: [
                "CD1",
                "CD2",
                "NE1",
                "CE2",
                "CE3",
                "CZ2",
                "CZ3",
                "CH2",
                "HD1",
                "HE1",
                "HE3",
                "HZ2",
                "HZ3",
                "HH2",
            ],
        },
        "rotamers": [
            [62, -90],
            [62, 90],
            [-177, -105],
            [-177, 90],
            [-65, -90],
            [-65, -5],
            [-65, 95],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.200813, 5.026064, 1.321087],
            [4.023453, 5.931084, 2.293240],
            [5.083390, 5.623004, 0.411545],
            [4.811943, 7.073555, 1.949808],
            [5.427347, 6.842060, 0.816764],
            [5.604041, 5.117355, -0.785636],
            [6.297161, 7.689052, 0.119605],
            [6.482659, 5.953119, -1.505101],
            [6.814091, 7.187011, -1.069023],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.068"],
            ["HB1", "H", "HCH2", "0.034"],
            ["HB2", "H", "HCH2", "0.034"],
            ["CG", "C", "CR5", "-0.214"],
            ["CD1", "C", "CR15", "0.059"],
            ["HD1", "H", "HCR5", "0.056"],
            ["NE1", "N", "NR15", "-0.080"],
            ["HE1", "H", "HNR5", "0.179"],
            ["CE2", "C", "CR56", "0.109"],
            ["CD2", "C", "CR56", "-0.038"],
            ["CE3", "C", "CR16", "-0.081"],
            ["HE3", "H", "HCR6", "0.058"],
            ["CZ3", "C", "CR16", "-0.094"],
            ["HZ3", "H", "HCR6", "0.052"],
            ["CH2", "C", "CR16", "-0.053"],
            ["HH2", "H", "HCR6", "0.053"],
            ["CZ2", "C", "CR16", "-0.053"],
            ["HZ2", "H", "HCR6", "0.053"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD1", "CD2"],
            "CD1": ["CG", "NE1"],
            "HD1": ["CD1"],
            "NE1": ["CD1", "CE2"],
            "HE1": ["NE1"],
            "CE2": ["CD2", "NE1", "CZ2"],
            "CD2": ["CG", "CE2", "CE3"],
            "HE3": ["CE3"],
            "CE3": ["CD2", "CZ3"],
            "CZ3": ["CE3", "CH2"],
            "HZ3": ["CZ3"],
            "CH2": ["CZ2", "CZ3"],
            "HH2": ["CH2"],
            "CZ2": ["CE2", "CH2"],
            "HZ2": ["CZ2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom_id, List of bonds
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.498, 0.031]},
            "CG": {"CD2": [1.433, 0.018], "CD1": [1.365, 0.025]},
            "CD1": {"HD1": [0.930, 0.020], "NE1": [1.374, 0.021]},
            "NE1": {"HE1": [0.860, 0.020], "CE2": [1.370, 0.011]},
            "CE2": {"CZ2": [1.394, 0.021], "CD2": [1.409, 0.017]},
            "CD2": {"CE3": [1.398, 0.016], "CE2": [1.409, 0.017]},
            "CE3": {"HE3": [0.930, 0.020], "CZ3": [1.382, 0.030]},
            "CZ3": {"HZ3": [0.930, 0.020], "CH2": [1.400, 0.025]},
            "CH2": {"HH2": [0.930, 0.020], "CZ2": [1.368, 0.019]},
            "CZ2": {"HZ2": [0.930, 0.020], "CH2": [1.368, 0.019]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Dist, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [113.600, 1.900]],
            [["CB", "CG", "CD2"], [126.800, 1.400]],
            [["CD1", "CG", "CD2"], [106.300, 1.600]],
            [["CB", "CG", "CD1"], [126.900, 1.500]],
            [["HD1", "CD1", "NE1"], [124.900, 3.000]],
            [["CG", "CD1", "HD1"], [124.900, 3.000]],
            [["CG", "CD1", "NE1"], [110.200, 1.300]],
            [["HE1", "NE1", "CE2"], [125.550, 3.000]],
            [["CD1", "NE1", "HE1"], [125.550, 3.000]],
            [["CD1", "NE1", "CE2"], [108.900, 1.800]],
            [["NE1", "CE2", "CZ2"], [130.100, 1.500]],
            [["CD2", "CE2", "CZ2"], [122.400, 1.000]],
            [["NE1", "CE2", "CD2"], [107.400, 1.300]],
            [["CE2", "CD2", "CE3"], [118.800, 1.000]],
            [["CE2", "CD2", "CG"], [107.200, 1.200]],
            [["CG", "CD2", "CE2"], [107.200, 1.200]],
            [["CG", "CD2", "CE3"], [133.900, 1.000]],
            [["HE3", "CE3", "CZ3"], [120.700, 3.000]],
            [["CD2", "CE3", "HE3"], [120.700, 3.000]],
            [["CD2", "CE3", "CZ3"], [118.600, 1.300]],
            [["HZ3", "CZ3", "CH2"], [119.450, 3.000]],
            [["CE3", "CZ3", "HZ3"], [119.450, 3.000]],
            [["CE3", "CZ3", "CH2"], [121.100, 1.300]],
            [["HH2", "CH2", "CZ2"], [119.250, 3.000]],
            [["CZ3", "CH2", "HH2"], [119.250, 3.000]],
            [["CZ3", "CH2", "CZ2"], [121.500, 1.300]],
            [["CH2", "CZ2", "HZ2"], [121.250, 3.000]],
            [["CE2", "CZ2", "HZ2"], [121.250, 3.000]],
            [["CH2", "CZ2", "CE2"], [117.500, 1.300]],
            [["CE2", "CZ2", "CH2"], [117.500, 1.300]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.66]],
            [["CA", "CB", "CG", "CD2"], ["CD1", 180.0]],
            [["CB", "CG", "CD2", "CE2"], [180]],
            [["CB", "CG", "CD1", "NE1"], [180]],
            [["CB", "CG", "CD2", "CE3"], [0.0]],
            [["CG", "CD2", "CE2", "CZ2"], [180]],
            [["CG", "CD2", "CE3", "CZ3"], [180]],
            [["CD2", "CE2", "CZ2", "CH2"], [0]],
        ],
    },
    # Tyrosine
    "TYR": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "CD1",
            "CD2",
            "CE1",
            "CE2",
            "CZ",
            "OH",
        ],
        "hydrogens": "H HA HB2 HB3 HD1 HD2 HE1 HE2 HH".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "CD1"],
            ["CD1", "CE1"],
            ["CG", "CD2"],
            ["CD2", "CE2"],
            ["CE1", "CZ"],
            ["CE2", "CZ"],
            ["CZ", "OH"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CD1", "HD1"],
            ["CD2", "HD2"],
            ["CE1", "HE1"],
            ["CE2", "HE2"],
            ["OH", "HH"],
        ],
        "nchi": 2,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "CD1"],
        },
        "chi-rotate": {
            1: [
                "CG",
                "CD1",
                "CD2",
                "CE1",
                "CE2",
                "CZ",
                "OH",
                "HB2",
                "HB3",
                "HD1",
                "HD2",
                "HE1",
                "HE2",
                "HH",
            ],
            2: [
                "CD1",
                "CD2",
                "CE1",
                "CE2",
                "CZ",
                "OH",
                "HD1",
                "HD2",
                "HE1",
                "HE2",
                "HH",
            ],
        },
        "rotamers": [
            [-177, 80],
            [62, 90],
            [-65, -85],
            [-65, -30],
            [-177, -80],
            [62, -90],
            [-65, 85],
            [-65, 30],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.267328, 4.996267, 1.194946],
            [4.059927, 5.918911, 2.227280],
            [5.114806, 5.318263, 0.128119],
            [4.699998, 7.163547, 2.192791],
            [5.754875, 6.562900, 0.093635],
            [5.547471, 7.485542, 1.125970],
            [6.169255, 8.694617, 1.092468],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.054"],
            ["HB1", "H", "HCH2", "0.049"],
            ["HB2", "H", "HCH2", "0.049"],
            ["CG", "C", "CR6", "-0.044"],
            ["CD1", "C", "CR16", "-0.053"],
            ["HD1", "H", "HCR6", "0.053"],
            ["CE1", "C", "CR16", "-0.099"],
            ["HE1", "H", "HCR6", "0.054"],
            ["CZ", "C", "CR6", "0.176"],
            ["OH", "O", "OH1", "-0.391"],
            ["HH", "H", "HOH1", "0.305"],
            ["CE2", "C", "CR16", "-0.099"],
            ["HE2", "H", "HCR6", "0.054"],
            ["CD2", "C", "CR16", "-0.053"],
            ["HD2", "H", "HCR6", "0.053"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "CD1"],
            "CD1": ["CG", "CE1"],
            "HD1": ["CD1"],
            "CE1": ["CD1", "CZ"],
            "HE1": ["CE1"],
            "CZ": ["CE1", "CE2"],
            "OH": ["CZ", "HH"],
            "HH": ["OH"],
            "CE2": ["CZ", "CD2"],
            "HE2": ["CE2"],
            "CD2": ["CE2", "HD2"],
            "HD2": ["CD2"],
            "C": ["CA", "END"],
            "O": ["C"],
            "CD2": ["CG", "ADD"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.530, 0.020], "C": [1.525, 0.021]},
            "CB": {"HB1": [0.970, 0.020], "HB2": [0.970, 0.020], "CG": [1.512, 0.022]},
            "CG": {"CD1": [1.389, 0.021], "CD2": [1.389, 0.021]},
            "CD1": {"HD1": [0.930, 0.020], "CE1": [1.382, 0.030]},
            "CE1": {"HE1": [0.930, 0.020], "CZ": [1.378, 0.024]},
            "CZ": {"OH": [1.376, 0.021], "CE2": [1.378, 0.024]},
            "OH": {"HH": [0.820, 0.020]},
            "CE2": {"HE2": [0.930, 0.020], "CD2": [1.382, 0.030]},
            "CD2": {"HD2": [0.930, 0.020]},
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["C", "CA", "CB"], [110.100, 1.900]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [113.900, 1.800]],
            [["CB", "CG", "CD2"], [120.800, 1.500]],
            [["CD1", "CG", "CD2"], [118.100, 1.500]],
            [["CB", "CG", "CD1"], [120.800, 1.500]],
            [["HD1", "CD1", "CE1"], [119.400, 3.000]],
            [["CG", "CD1", "HD1"], [119.400, 3.000]],
            [["CG", "CD1", "CE1"], [121.200, 1.500]],
            [["HD2", "CD2", "CE2"], [119.400, 3.000]],
            [["CG", "CD2", "HD2"], [119.400, 3.000]],
            [["CG", "CD2", "CE2"], [121.200, 1.500]],
            [["HE1", "CE1", "CZ"], [120.200, 3.000]],
            [["CD1", "CE1", "HE1"], [120.200, 3.000]],
            [["CD1", "CE1", "CZ"], [119.600, 1.800]],
            [["OH", "CZ", "CE2"], [119.900, 3.000]],
            [["CE1", "CZ", "OH"], [119.900, 3.000]],
            [["CZ", "OH", "HH"], [110.000, 3.000]],
            [["CE1", "CZ", "CE2"], [120.300, 2.000]],
            [["HE2", "CE2", "CD2"], [120.200, 3.000]],
            [["CZ", "CE2", "HE2"], [120.200, 3.000]],
            [["CZ", "CE2", "CD2"], [119.600, 1.800]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.60]],
            [["CA", "CB", "CG", "CD2"], ["CD1", 180]],
            [["CB", "CG", "CD1", "CE1"], [180]],
            [["CD1", "CE1", "CZ", "CE2"], [0]],
            [["CE1", "CZ", "CE2", "CD2"], [0]],
            [["CZ", "CE2", "CD2", "CG"], [0]],
            [["CB", "CG", "CD2", "CE2"], [180]],
            [["CG", "CD1", "CE1", "CZ"], [0]],
            [["OH", "CZ", "CE1", "CD1"], [180]],
            [["CD1", "CE1", "CZ", "OH"], [180]],
        ],
    },
    # Valine
    "VAL": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG1",
            "CG2",
        ],
        "hydrogens": "H HA HB HG11 HG12 HG13 HG21 HG22 HG23".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG1"],
            ["CB", "CG2"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB"],
            ["CG1", "HG11"],
            ["CG1", "HG12"],
            ["CG1", "HG13"],
            ["CG2", "HG21"],
            ["CG2", "HG22"],
            ["CG2", "HG23"],
        ],
        "nchi": 1,
        "chi": {
            1: ["N", "CA", "CB", "CG1"],
        },
        "chi-rotate": {
            1: ["CG1", "CG2", "HB", "HG11", "HG12", "HG13", "HG21", "HG22", "HG23"],
        },
        "rotamers": [
            [63],
            [175],
            [-60],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [3.997712, 2.900483, 2.489542],
            [4.274186, 5.009602, 1.194577],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH1", "-0.038"],
            ["HB", "H", "HCH1", "0.038"],
            ["CG1", "C", "CH3", "-0.114"],
            ["HG11", "H", "HCH3", "0.038"],
            ["HG12", "H", "HCH3", "0.038"],
            ["HG13", "H", "HCH3", "0.038"],
            ["CG2", "C", "CH3", "-0.114"],
            ["HG21", "H", "HCH3", "0.038"],
            ["HG22", "H", "HCH3", "0.038"],
            ["HG23", "H", "HCH3", "0.038"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG2"],
            "HB": ["CB"],
            "CG1": ["CB", "HG13"],
            "HG11": ["CG1"],
            "HG12": ["CG1"],
            "HG13": ["CG1"],
            "CG2": ["CB", "HG23"],
            "HG21": ["CG2"],
            "HG22": ["CG2"],
            "HG23": ["CG2"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": {
            # Atom1_id, Atom2_id, Dist, SD
            "N": {"H": [0.860, 0.020], "CA": [1.458, 0.019]},
            "CA": {"HA": [0.980, 0.020], "CB": [1.540, 0.027], "C": [1.525, 0.021]},
            "CB": {"HB": [0.980, 0.020], "CG1": [1.521, 0.033], "CG2": [1.521, 0.033]},
            "CG1": {
                "HG11": [0.960, 0.020],
                "HG12": [0.960, 0.020],
                "HG13": [0.960, 0.020],
            },
            "CG2": {
                "HG21": [0.960, 0.020],
                "HG22": [0.960, 0.020],
                "HG23": [0.960, 0.020],
            },
            "C": {"O": [1.231, 0.020]},
        },
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [109.100, 2.200]],
            [["C", "CA", "CB"], [109.100, 2.200]],
            [["HA", "CA", "C"], [109.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [111.500, 1.700]],
            [["HB", "CB", "CG1"], [108.000, 3.000]],
            [["CG1", "CB", "CG2"], [110.800, 2.200]],
            [["HB", "CB", "CG2"], [108.000, 3.000]],
            [["CA", "CB", "HB"], [109.000, 3.000]],
            [["CA", "CB", "CG1"], [110.400, 1.700]],
            [["HG11", "CG1", "HG12"], [110.000, 3.000]],
            [["HG12", "CG1", "HG13"], [110.000, 3.000]],
            [["HG11", "CG1", "HG13"], [110.000, 3.000]],
            [["CB", "CG1", "HG11"], [109.000, 3.000]],
            [["CB", "CG1", "HG12"], [109.000, 3.000]],
            [["CB", "CG1", "HG13"], [109.000, 3.000]],
            [["CA", "CB", "CG2"], [110.400, 1.700]],
            [["HG21", "CG2", "HG22"], [110.000, 3.000]],
            [["HG22", "CG2", "HG23"], [110.000, 3.000]],
            [["HG21", "CG2", "HG23"], [110.000, 3.000]],
            [["CB", "CG2", "HG21"], [109.000, 3.000]],
            [["CB", "CG2", "HG22"], [109.000, 3.000]],
            [["CB", "CG2", "HG23"], [109.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
        "dihedral": [
            [["N", "C", "CA", "CB"], [122.60]],
            [["N", "CA", "CB", "CG2"], ["CG1", 120]],
        ],
    },
    # Selenomethionine
    "MSE": {
        "atoms": [
            "N",
            "CA",
            "C",
            "O",
            "CB",
            "CG",
            "SE",
            "CE",
        ],
        "hydrogens": "H HA HB2 HB3 HG2 HG3 HE1 HE2 HE3".split(),
        "bonds": [
            ["N", "CA"],
            ["CA", "C"],
            ["C", "O"],
            ["CA", "CB"],
            ["CB", "CG"],
            ["CG", "SE"],
            ["SE", "CE"],
            ["N", "H"],
            ["CA", "HA"],
            ["CB", "HB2"],
            ["CB", "HB3"],
            ["CG", "HG2"],
            ["CG", "HG3"],
            ["CE", "HE1"],
            ["CE", "HE2"],
            ["CE", "HE3"],
        ],
        "nchi": 3,
        "chi": {
            1: ["N", "CA", "CB", "CG"],
            2: ["CA", "CB", "CG", "SE"],
            3: ["CB", "CG", "SE", "CE"],
        },
        "chi-rotate": {
            1: ["CG", "SE", "CE", "HB2", "HB3", "HG2", "HG3", "HE1", "HE2", "HE3"],
            2: ["SE", "CE", "HG2", "HG3", "HE1", "HE2", "HE3"],
            3: ["CE", "HE1", "HE2", "HE3"],
        },
        # A blatant copy of MET
        "rotamers": [
            [62, 180, 75],
            [62, 180, -75],
            [-177, 65, 75],
            [-177, 65, 180],
            [-177, 180, 75],
            [-177, 180, 180],
            [-177, 180, -75],
            [-67, 180, 75],
            [-67, 180, 180],
            [-67, 180, -75],
            [-65, -65, 103],
            [-65, -65, 180],
            [-65, -65, -70],
        ],
        "positions": [
            [3.325770, 1.547909, -1.607204e-06],
            [3.970048, 2.845795, -1.311163e-07],
            [5.485541, 2.705207, -4.398755e-06],
            [6.008824, 1.593175, -8.449768e-06],
            [3.576965, 3.653838, 1.232143],
            [4.274186, 5.009602, 1.194577],
            [3.817309, 5.981266, 2.651708],
            [4.753212, 7.463128, 2.340949],
        ],
        "partial_charge": [
            # Atom_id, Element, Type, Partial Charge
            ["N", "N", "NH1", "-0.204"],
            ["H", "H", "HNH1", "0.204"],
            ["CA", "C", "CH1", "0.058"],
            ["HA", "H", "HCH1", "0.046"],
            ["CB", "C", "CH2", "-0.076"],
            ["HB1", "H", "HCH2", "0.038"],
            ["HB2", "H", "HCH2", "0.038"],
            ["CG", "C", "CH2", "-0.024"],
            ["HG1", "H", "HCH2", "0.041"],
            ["HG2", "H", "HCH2", "0.041"],
            ["SE", "SE", "SE", "-0.058"],
            ["CE", "C", "CH3", "-0.150"],
            ["HE1", "H", "HCH3", "0.050"],
            ["HE2", "H", "HCH3", "0.050"],
            ["HE3", "H", "HCH3", "0.050"],
            ["C", "C", "C", "0.318"],
            ["O", "O", "O", "-0.422"],
        ],
        "connectivity": {
            # Atom_id, List of bonds
            "N": ["n/a", "CA", "START"],
            "H": ["N"],
            "CA": ["N", "C"],
            "HA": ["CA"],
            "CB": ["CA", "CG"],
            "HB1": ["CB"],
            "HB2": ["CB"],
            "CG": ["CB", "SE"],
            "HG1": ["CG"],
            "HG2": ["CG"],
            "SE": ["CG", "CE"],
            "CE": ["SE", "HE3"],
            "HE1": ["CE"],
            "HE2": ["CE"],
            "HE3": ["CE"],
            "C": ["CA", "END"],
            "O": ["C"],
        },
        "bond_dist": [
            # Atom1_id, Atom2_id, Dist, SD
            [["N", "H"], [0.860, 0.020]],
            [["N", "CA"], [1.458, 0.019]],
            [["CA", "HA"], [0.980, 0.020]],
            [["CA", "CB"], [1.530, 0.020]],
            [["CB", "HB1"], [0.970, 0.020]],
            [["CB", "HB2"], [0.970, 0.020]],
            [["CB", "CG"], [1.520, 0.030]],
            [["CG", "HG1"], [0.970, 0.020]],
            [["CG", "HG2"], [0.970, 0.020]],
            [["CG", "SE"], [1.950, 0.030]],
            [["SE", "CE"], [1.950, 0.030]],
            [["CE", "HE1"], [0.960, 0.020]],
            [["CE", "HE2"], [0.960, 0.020]],
            [["CE", "HE3"], [0.960, 0.020]],
            [["CA", "C"], [1.525, 0.021]],
            [["C", "O"], [1.231, 0.020]],
        ],
        "bond_angle": [
            # Atom1_id, Atom2_id, Angle, SD
            [["H", "N", "CA"], [114.000, 3.000]],
            [["HA", "CA", "CB"], [109.000, 3.000]],
            [["CB", "CA", "C"], [110.100, 1.900]],
            [["HA", "CA", "C"], [110.000, 3.000]],
            [["N", "CA", "HA"], [110.000, 3.000]],
            [["N", "CA", "CB"], [110.500, 1.700]],
            [["HB1", "CB", "HB2"], [110.000, 3.000]],
            [["HB2", "CB", "CG"], [108.000, 3.000]],
            [["HB1", "CB", "CG"], [108.000, 3.000]],
            [["CA", "CB", "HB1"], [109.000, 3.000]],
            [["CA", "CB", "HB2"], [109.000, 3.000]],
            [["CA", "CB", "CG"], [114.100, 2.000]],
            [["HG1", "CG", "HG2"], [110.000, 3.000]],
            [["HG2", "CG", "SE"], [108.000, 3.000]],
            [["HG1", "CG", "SE"], [108.000, 3.000]],
            [["CB", "CG", "HG1"], [109.000, 3.000]],
            [["CB", "CG", "HG2"], [109.000, 3.000]],
            [["CB", "CG", "SE"], [112.700, 3.000]],
            [["CG", "SE", "CE"], [98.923, 2.200]],
            [["HE1", "CE", "HE2"], [110.000, 3.000]],
            [["HE2", "CE", "HE3"], [110.000, 3.000]],
            [["HE1", "CE", "HE3"], [110.000, 3.000]],
            [["SE", "CE", "HE1"], [109.000, 3.000]],
            [["SE", "CE", "HE2"], [109.000, 3.000]],
            [["SE", "CE", "HE3"], [109.000, 3.000]],
            [["N", "CA", "C"], [111.200, 2.800]],
            [["CA", "C", "O"], [120.800, 1.700]],
        ],
    },
}
